@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.5"
+    version = "1.8.6"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -113,8 +113,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         project = activity.project
         group = activity.group
 
-        if activity.data is None:
-            self._post(group, project, activity)
+        self._post(group, project, activity)
 
     def _post(self, group, project, event=''):
         custom_keyword = self.get_option("custom_keyword", project)
@@ -133,6 +132,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
         payload = f"{payload} > Hi: {event.__dict__} \n\n"
+        payload = f"{payload} > Hi: {event.data} \n\n"
         # payload = f"{payload} > Group: {group.__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
